function D = DdiffKZ0(v,t,x,alpha,zeta,beta);

%_________________________________________________________________________________ 
% DdiffKZ0.m
% Arguments: v (saddlepoint), t (point of domain), x (point of contamination), 
% alpha >= 1, zeta > 0 (Weibull parameters), beta > 0 (security loading)
% This function computes the derivatives of the c.g.f. of the compound geometric
% sum with tail integrated Weibull summands, w.r.t. to the argument and to the 
% contamination amount eps, evaluated at eps = 0 and at the saddlepoint 
%_________________________________________________________________________________ 

K = diffK(v,alpha,zeta);
M = diffMN(K(1),beta); 

rho = beta/(1+beta);  

KZ0 = log((M(1)-rho)/(1-rho));
d2KZ0 = t*(M(3)*K(2)/M(2)+K(3)/K(2)-t); 
DKZ0 = t*(exp(-K(1))*(exp(v*x)-1)/(v*x)-1)/K(2);    

D = [KZ0 d2KZ0 DKZ0]; 
% dj is the jth differentation w.r.t. the argument of the cgf and D is the 
% differentiation w.r.t. the amount of contamination eps and at eps = 0

