function f = sadstab(t,v,D,rho)

%_____________________________________________________________________________________ 
% sadstab.m
% Arguments: t (point of domain), v (saddlepoint), D (vector 
% [KZ0, d2KZ0 DKZ0], where d is differentation w.r.t. argument, D 
% w.r.t. contamination amount eps and at eps = 0), rho (geometric parameter)      
% This function computes the saddlepoint approximation to the s.f. and its stability
% under uniform perturbation of the compound geometric sum with
% tail integrated Weibull summands, thus to the probability of ruin
%_____________________________________________________________________________________ 

KZ0 = D(1);
d2KZ0 = D(2);
DKZ0 = D(3);

Kt = v*t-KZ0;
Ktp = max(0,Kt);
r = sign(v)*sqrt(2*Ktp);  
s = v*sqrt(d2KZ0);
normdens = 1/sqrt(2*pi)*exp(-r^2/2);
dr = -DKZ0/r;

sf = (1-normal(r)+normdens*(1/s-1/r))*(1-rho); % s.f.
st = -normdens*(r*dr/s)*(1-rho); % s.f.s.
f = [sf st]; 

